% --- Source file: lookup.xport.Rd ---
\name{lookup.xport}
\alias{lookup.xport}
\title{Lookup Information on a SAS XPORT Format Library}
\description{
  Scans a file as a SAS XPORT format library and returns a list
  containing information about the SAS library.
}
\usage{
lookup.xport(file)
}
\arguments{
  \item{file}{character variable with the name of the file to read.  The
    file must be in SAS XPORT format.}
}
\value{
  A list with one component for each dataset in the XPORT format library.
}
\references{
  SAS Technical Support document TS-140:
  \dQuote{The Record Layout of a Data Set in SAS Transport (XPORT) Format}
  available as
  \url{http://ftp.sas.com/techsup/download/technote/ts140.html}.
} 
\author{Saikat DebRoy}
\seealso{
  \code{\link{read.xport}}
}
\examples{
\dontrun{
lookup.xport("transport")
}
}
\keyword{file}
\eof
% --- Source file: read.S.Rd ---
\name{S3 read functions}
\alias{data.restore}
\alias{read.S}
\title{Read an S3 Binary or data.dump File}
\description{
  Reads binary data files or \code{data.dump} files that were produced
  in S version 3.
}
\usage{
  data.restore(file, print = FALSE, verbose = FALSE, env = .GlobalEnv)
  read.S(file)
}
\arguments{
  \item{file}{the filename of the S-PLUS \code{data.dump} or binary
    file.}
  \item{print}{whether to print the name of each object as read from the
    file.}
  \item{verbose}{whether to print the name of every subitem within each
    object.}
  \item{env}{environment within which to create the restored object(s).}
}
\value{
  for \code{read.S}, an R version of the S3 object.

  for \code{data.restore}, the name of the file.
}
\details{
  \code{read.S} can read the binary files produced in some older
  versions of S-PLUS on either Windows (versions 3.x, 4.x, 2000) or Unix
  (version 3.x with 4 byte integers).  It automatically detects whether
  the file was produced on a big- or little-endian machine and adapts
  itself accordingly.

  \code{data.restore} can read a similar range of files produced by
  \code{data.dump} and for newer versions of S-PLUS, those from
  \code{data.dump(....., oldStyle=TRUE)}.

  Not all S3 objects can be handled in the current version.  The most
  frequently encountered exceptions are functions and expressions; you
  will also have trouble with objects that contain model formulas.  In
  particular, comments will be lost from function bodies, and the
  argument lists of functions will often be changed.
}
\author{
  Duncan Murdoch
}
\examples{
\dontrun{read.S(file.path("_Data", "myobj"))
data.restore("dumpdata", print = TRUE)
}}
\keyword{data}
\keyword{file}
\eof
% --- Source file: read.dbf.Rd ---
\name{read.dbf}
\alias{read.dbf}
\title{Read a DBF File}
\description{
  The function reads a DBF file into a data frame, converting character
  fields to factors, and trying to respect NULL fields.
}
\usage{
read.dbf(file, as.is = FALSE)
}
\arguments{
  \item{file}{name of input file}
  \item{as.is}{should character vectors not be converted to factors?}
}
\details{
  DBF is the extension used for files written for the \sQuote{XBASE}
  family of database languages, \sQuote{covering the dBase, Clipper,
    FoxPro, and their Windows equivalents Visual dBase, Visual Objects,
    and Visual FoxPro, plus some older products}
  (\url{http://www.clicketyclick.dk/databases/xbase/format/}).
  Most of these follow the file structure used by Ashton-Tate's dBase
  II, III or 4 (later owned by Borland).

  \code{read.dbf} is based on C code from
  \url{http://shapelib.maptools.org/} which implements the
  \sQuote{XBASE} specification.  It can convert fields of type
  \code{"L"} (logical), \code{"N"} and \code{"F"} (numeric and float)
  and \code{"D"} (dates): all other field types are read as-is as
  character vectors.  A numeric field are read as an \R integer vector if
  it is encoded to have no decimals, otherwise as a numeric vector.  However,
  if the numbers are too large to fit into an integer vector, it is
  changed to numeric.  Note that is possible to read integers that cannot be
  represented exactly even as doubles: this sometimes occurs if IDs are
  incorrectly coded as numeric.
}

\value{
  A data frame of data from the DBF file; note that the field names are
  adjusted to use in R using \code{\link{make.names}(unique=TRUE)}.

  There is an attribute \code{"data_type"} giving the single-character
  dBase types for each field.
}

\references{
  \url{http://shapelib.maptools.org/}.

  The Borland file specification \emph{via}
  \url{http://www.wotsit.org/search.asp?s=database}.
}

\author{
  Nicholas Lewin-Koh and Roger Bivand; shapelib by Frank Warmerdam
}

\seealso{
  \code{\link{write.dbf}}
}
\examples{
x <- read.dbf(system.file("files/sids.dbf", package="foreign")[1])
str(x)
summary(x)
}
\keyword{file}
\eof
% --- Source file: read.dta.Rd ---
\name{read.dta}
\alias{read.dta}
\title{Read Stata Binary Files}
\description{
  Reads a file in Stata version 5-9  binary format into a data frame. 
}
\usage{
read.dta(file, convert.dates = TRUE, tz = NULL,
         convert.factors = TRUE, missing.type = FALSE,
         convert.underscore=TRUE, warn.missing.labels=TRUE)
}
\arguments{
  \item{file}{a filename as a character string.}
  \item{convert.dates}{Convert Stata dates to \code{Date} class?}
  \item{tz}{Previously used to specify time zone. Now deprecated.}
  \item{convert.factors}{Use Stata value labels to create factors?
    (version 6.0 or later).}
  \item{missing.type}{For version 8,9 only, store information about
    different types of missing data?}
  \item{convert.underscore}{Convert \code{"_"} in Stata variable names
    to \code{"."} in R names?}
  \item{warn.missing.labels}{Warn if a variable is specified with value
    labels and those value labels are not present in the file.}
}
\details{
  The variables in the Stata data set become the columns of the data
  frame.  Missing values are correctly handled.  The data label,
  variable labels, and timestamp are stored as attributes of the data
  frame.  Nothing is done with variable characteristics.

  Optionally, Stata dates (\%d formats) are converted to \R's
  \code{Date} class and variables with Stata value labels are
  converted to factors. Ordinarily, \code{read.dta} will not convert
  a variable to a factor unless a label is present for every level. Use
  \code{convert.factors=NA} to override this. In any case the value
  label and format information is stored as attributes on the returned data frame. 

  Stata 8.0 introduced a system of 27 different missing data values. If
  \code{missing.type}
  is \code{TRUE} a separate list is created with the same variable
  names as the loaded data. For string variables the list value is
  \code{NULL}. For other variables the value is \code{NA} where the
  observation is not missing and 0-26 when the observation is
  missing. This is attached as the code{"missing"} attribute of the
  returned value.
  
  The option to allow underscores in variable names may become the
  default in future versions now that R supports their use.
}
\value{
  a data frame
}
\references{
  Stata Users Manual (versions 5 & 6), Programming manual (version 7),
  or online help (version 8,9) describe the format of the files.
}

\author{Thomas Lumley}
\seealso{
  \code{\link{write.dta}},
  \code{\link{attributes}}
  \code{\link{Date}}
  \code{\link{factor}}
}
\examples{
data(swiss)
write.dta(swiss,swissfile<-tempfile())
read.dta(swissfile)
}
\keyword{file}
\eof
% --- Source file: read.epiinfo.Rd ---
\name{read.epiinfo}
\alias{read.epiinfo}
\title{Read Epi Info Data Files}
\description{
  Reads data files in the \code{.REC} format used by Epi Info versions 6
  and earlier and by EpiData.  Epi Info is a public domain database and
  statistics package produced by the US Centers for Disease Control
  and EpiData is a freely available data entry and validation system.
  }
\usage{
read.epiinfo(file, read.deleted = FALSE, guess.broken.dates = FALSE,
             thisyear = NULL, lower.case.names = FALSE)
}
\arguments{
  \item{file}{A filename, URL, or connnection.}
  \item{read.deleted}{Deleted records are read if \code{TRUE}, omitted
    if \code{FALSE} or replaced with \code{NA} if \code{NA}.}
  \item{guess.broken.dates}{Attempt to convert dates with 0 or 2 digit
    year information (see Details below).}
  \item{thisyear}{A 4-digit year to use for dates with no year. Defaults
    to the current year.}
  \item{lower.case.names}{Convert variable names to lowercase?}
}
\details{
  Epi Info allows dates to be specified with no year or with a 2 or 4
  digits.  Dates with four-digit years are always converted to
  \code{Date} class.  With the \code{guess.broken.dates} option the function
  will attempt to convert two-digit years using the operating system's
  default method (see \link{Date}) and will use the current
  year or the \code{thisyear} argument for dates with no year
  information.

  If \code{read.deleted} is \code{TRUE} the \code{"deleted"} attribute
  of the data frame indicates the deleted records.
}
\note{  Epi Info 2000, the current version, uses the Microsoft Access file
  format to store data. This may be readable with the \code{RODBC} or
  \code{RDCOM} packages.
}
\value{
  A data frame.
}
\references{
  \url{http://www.cdc.gov/epiinfo/},
  \url{http://www.epidata.dk}
}

\seealso{
  \link{DateTimeClasses}
}

\examples{
\dontrun{
data<-read.epiinfo("oswego.rec",guess.broken.dates=TRUE,thisyear="1972")
}
}
\keyword{ file }
\eof
% --- Source file: read.mtp.Rd ---
\name{read.mtp}
\alias{read.mtp}
\title{Read a Minitab Portable Worksheet}
\description{
  Return a list with the data stored in a file as a Minitab Portable
  Worksheet.
}
\usage{
read.mtp(file)
}
\arguments{
  \item{file}{character variable with the name of the file to read.  The
    file must be in Minitab Portable Worksheet format.}
}
\value{
  A list with one component for each column, matrix, or constant stored
  in the Minitab worksheet.
}
\references{
  \url{http://www.minitab.com/}
}
\author{Douglas M. Bates}
\examples{
\dontrun{
read.mtp("ex1-10.mtp")
}
}
\keyword{file}
\eof
% --- Source file: read.octave.Rd ---
\name{read.octave}
\alias{read.octave}
\title{Read Octave Text Data Files}
\description{
  Read a file in Octave text data format into a list.
}
\usage{
read.octave(file)
}
\arguments{
  \item{file}{a character string with the name of the file to read.}
}
\details{
  This function is used to read in files in Octave text data format, as
  created by \code{save -ascii} in Octave.  It knows about most of the
  common types of variables, including the standard atomic (real and
  complex scalars, matrices, and \eqn{N}-d arrays, strings, ranges, and
  boolean scalars and matrices) and recursive (structs, cells, and
  lists) ones, but has no guarantee to read all types.  If a type is not
  recognized, a warning indicating the unknown type is issued, it is
  attempted to skip the unknown entry, and \code{NULL} is used as its
  value.  Note that this will give incorrect results, and maybe even
  errors, in the case of unknown recursive data types.

  As Octave can read MATLAB binary files, one can make the contents of
  such files available to R by using Octave's load and save (as text)
  facilities as an intermediary step.
}
\value{
  A list with one named component for each variable in the file.
}
\references{\url{http://www.octave.org/}}
\author{Stephen Eglen \email{stephen@gnu.org} and Kurt Hornik}
\keyword{file}
\eof
% --- Source file: read.spss.Rd ---
\name{read.spss}
\alias{read.spss}
\title{Read an SPSS Data File}
\description{
  \code{read.spss} reads a file stored by the SPSS \code{save} and
  \code{export} commands and returns a list.
}
\usage{
read.spss(file, use.value.labels=TRUE, to.data.frame=FALSE,
          max.value.labels=Inf, trim.factor.names=FALSE)
}
\arguments{
  \item{file}{ character variable with the name of the file to read.}
  \item{use.value.labels}{ Convert variables with value labels into \R
    factors with those levels?}
  \item{to.data.frame}{return a data frame?}
  \item{max.value.labels}{Only variables with at most this many unique
    values will be converted to factors}
  \item{trim.factor.names}{Trim trailing spaces from factor levels?}
}
\value{
  A list (or data frame) with one component for each variable in the saved data set.
}
\details{
  This uses modified code from the PSPP project for reading the SPSS
  formats. 
  
  Occasionally in SPSS value labels will be added to some values of a
  continuous variable (eg to distinguish different types of missing
  data), and you will not want these variables converted to factors.  By
  setting \code{max.val.labels} you can specify that variables with a
  large number of distinct values are not converted to factors even if
  they have value labels. In addition, variables will not be converted
  to factors if there are non-missing values that have no value label.
  The value labels are then returned in the \code{"value.labels"}
  attribute of the variable.
  
  If SPSS variable labels are present, they are returned as the
  \code{"variable.labels"} attribute of the answer.

  Fixed length strings (including value labels) are padded on the right
  with spaces by SPSS, and so are read that way by R.   See the examples
  for \code{\link{sub}} for ways to remove trailing spaces in string data.
}
\note{
  If SPSS value labels are converted to factors the underlying numerical
  codes will not in general be the same as the SPSS numerical
  values, since the numerical codes in R are always 1,2,3,...
}
\author{Saikat DebRoy}
\examples{
\dontrun{
read.spss("datafile")
## don't convert value labels to factor levels
read.spss("datafile",use.value.labels=FALSE)
## convert value labels to factors for variables with at most
## ten distinct values.
read.spss("datafile",max.val.labels=10)
}
}
\keyword{file}
\eof
% --- Source file: read.ssd.Rd ---
\name{read.ssd}
\alias{read.ssd}
\title{Obtain a Data Frame from a SAS Permanent Dataset, via read.xport }
\description{
  Generates a SAS program to convert the ssd contents to SAS transport format
  and then uses \code{read.xport} to obtain a dataframe.
}
\usage{
read.ssd(libname, sectionnames, 
   tmpXport=tempfile(), tmpProgLoc=tempfile(), sascmd="sas")
}
\arguments{
  \item{libname}{character string defining the SAS library (usually a
    directory reference)}
  \item{sectionnames}{character vector giving member names. These are
    files in the \code{libname} directory. They will usually have a
    \code{.ssd0x} or \code{.sas7bdat} extension, which should be omitted.}
  \item{tmpXport}{character  string: location where temporary xport
    format archive should reside -- defaults to a randomly named file
    in the session temporary directory, which will be removed.}
  \item{tmpProgLoc}{character  string: location where temporary
    conversion SAS program should reside -- defaults to a randomly named
    file in session temporary directory, which will be removed on
    successful operation.}
  \item{sascmd}{character string giving full path to SAS executable.}
}
\details{
  Creates a SAS program and runs it.
}
\value{
  A data frame if all goes well, or NULL with warnings and some
  enduring side effects (log file for auditing)
}
\author{
  For Unix: VJ Carey \email{<stvjc@channing.harvard.edu>}
}
\note{ error handling is primitive }
\seealso{\code{\link{read.xport}}}
\examples{
## if there were some files on the web we could get a real
## runnable example
\dontrun{
R> list.files("trialdata")
 [1] "baseline.sas7bdat" "form11.sas7bdat"   "form12.sas7bdat"  
 [4] "form13.sas7bdat"   "form22.sas7bdat"   "form23.sas7bdat"  
 [7] "form3.sas7bdat"    "form4.sas7bdat"    "form48.sas7bdat"  
[10] "form50.sas7bdat"   "form51.sas7bdat"   "form71.sas7bdat"  
[13] "form72.sas7bdat"   "form8.sas7bdat"    "form9.sas7bdat"   
[16] "form90.sas7bdat"   "form91.sas7bdat"  
R> baseline<-read.ssd("trialdata","baseline")
R> form90<-read.ssd("trialdata","form90")

## Or for a Windows example
sashome <- "/Program Files/SAS/SAS 9.1"
read.ssd(file.path(sashome, "core", "sashelp"), "retail",
         sascmd = file.path(sashome, "sas.exe"))
}
}
\keyword{file}
\eof
% --- Source file: read.systat.Rd ---
\name{read.systat}
\alias{read.systat}
\title{Obtain a Data Frame from a Systat File}
\description{
  \code{read.systat} reads a rectangular data file stored by the Systat
  \code{SAVE} command as (legacy) \code{*.sys} or more recently
  \code{*.syd} files.
}
\usage{
read.systat(file, to.data.frame = TRUE)
}
\arguments{
  \item{file}{character variable with the name of the file to read}
  \item{to.data.frame}{return a data frame (otherwise a list)}
}
\details{
  The function only reads those Systat files that are rectangular data
  files (\code{mtype = 1}), and warns when files have non-standard
  variable name codings.  The files tested were produced on MS-DOS and
  Windows: files for the Mac version of Systat have a completely
  different format.

  The C code was originally written for an add-on module for Systat
  described in Bivand (1992 paper).  Variable names retain the trailing
  dollar in the list returned when \code{to.data.frame} is \code{FALSE},
  and in that case character variables are returned as is and filled up
  to 12 characters with blanks on the right.  The original function was
  limited to reading Systat files with up to 256 variables (a Systat
  limitation); it will now read up to 8192 variables.

  If there is a user comment in the header this is returned as attribute
  \code{"comment"}.  Such comments are always a multiple of 72
  characters (with a maximum of 720 chars returned), normally padded with
  trailing spaces.
}

\value{
  A data frame (or list) with one component for each variable in the
  saved data set.
}

\references{
  Systat Manual, 1987, 1989\cr
 
  Bivand, R. S. (1992)
  SYSTAT-compatible software for modelling spatial dependence among
  observations. \emph{Computers and Geosciences} \bold{18}, 951--963.
}
\author{Roger Bivand}

\examples{
summary(iris)
iris.s <- read.systat(system.file("files/Iris.syd", package="foreign")[1])
str(iris.s)
summary(iris.s)
}
\keyword{file}
\eof
% --- Source file: read.xport.Rd ---
\name{read.xport}
\alias{read.xport}
\title{Read a SAS XPORT Format Library}
\description{
  Reads a file as a SAS XPORT format library and returns a list of
  data.frames.
}
\usage{
read.xport(file)
}
\arguments{
 \item{file}{character variable with the name of the file to read.  The
   file must be in SAS XPORT format.}
}
\value{
  If there is a more than one dataset in the XPORT format library, a named
  list of data frames, otherwise a data frame.  The columns of the data
  frames will be either numeric (corresponding to numeric in SAS) or
  factor (corresponding to character in SAS).  All SAS numeric missing
  values (including special missing values represented by \code{._},
  \code{.A} to \code{.Z} by SAS) are mapped to \R \code{NA}.

  Trailing blanks are removed from character columns before conversion to
  a factor.  Some sources claim that character missing values in SAS are
  represented by \code{' '} or \code{''}: these are not treated as \R
  missing values.
}
\references{
  SAS Technical Support document TS-140:
  ``The Record Layout of a Data Set in SAS Transport (XPORT) Format''
  available at
  \url{http://ftp.sas.com/techsup/download/technote/ts140.html}.
}
\author{Saikat DebRoy \email{<saikat@stat.wisc.edu>}}
\seealso{
  \code{\link{lookup.xport}}
}
\examples{
\dontrun{
read.xport("transport")
}
}
\keyword{file}
\eof
% --- Source file: write.dbf.Rd ---
\name{write.dbf}
\alias{write.dbf}
\title{Write a DBF File}
\description{
  The function tries to write a data frame to a DBF file.
}
\usage{
write.dbf(dataframe, file, factor2char = TRUE, max_nchar = 254)
}
\arguments{
  \item{dataframe}{a data frame object.}
  \item{file}{a file name to be written to.}
  \item{factor2char}{logical, default \code{TRUE}, convert factor columns to
    character: otherwise they are written as the internal integer codes.}
  \item{max_nchar}{The maximum number of characters allowed in a
    character field.  Strings which exceed this will be truncated with a
    warning.  See Details.}
}
\details{
  Dots in column names are replaced by underlines in the DBF file, and
  names are truncated to 11 characters.

  Only vector columns of classes \code{"logical"}, \code{"numeric"},
  \code{"integer"}, \code{"character"}, \code{"factor"} and
  \code{"Date"} can be written.  Other columns should be converted to
  one of these.
  
  Maximum precision (number of digits including minus sign and decimal
  sign) for numeric is 19 - scale (digits after the decimal sign) which is
  calculated internally based on the number of digits before the decimal
  sign.

  The original DBASE format limited character fields to 254 bytes.
  It is said that Clipper and FoxPro can read up to 32K, and it is
  possible to write a reader that could accept up to 65535 bytes.
  (The documentation suggests that only ASCII characters can be assumed
  to be supported.)  Readers expecting the older standard (which
  includes Excel 2003, Access 2003 and OpenOffice 2.0) will truncate the
  field to the maximum width modulo 256, so increase \code{max_nchar}
  only if you are sure the intended reader supports wider character fields.
}
\value{
  Invisible \code{NULL}.
}
\references{
  \url{http://shapelib.maptools.org/}

  \url{http://www.clicketyclick.dk/databases/xbase/format/data_types.html}
}
\note{
  Other applications have varying abilities to read the data types used
  here.  Microsoft Access reads \code{"numeric"}, \code{"integer"},
  \code{"character"} and \code{"Date"} fields, including recognizing
  missing values, but not \code{"logical"} (read as \code{0,-1}).
  Microsoft Excel understood all possible types but did not interpret missing
  values in character fields correctly (showing them as character nuls).
}

\author{
  Nicholas J. Lewin-Koh, modified by Roger Bivand and Brian Ripley;
  shapelib by Frank Warmerdam.
}

\seealso{
  \code{\link{read.dbf}}
}
\examples{
str(warpbreaks)
try1 <- paste(tempfile(), ".dbf", sep = "")
write.dbf(warpbreaks, try1, factor2char = FALSE)
in1 <- read.dbf(try1)
str(in1)
try2 <- paste(tempfile(), ".dbf", sep = "")
write.dbf(warpbreaks, try2, factor2char = TRUE)
in2 <- read.dbf(try2)
str(in2)
unlink(c(try1, try2))
\testonly{
DF <- data.frame(a=c(1:3, NA), b=c(NA, rep(pi, 3)),
                 c=c(TRUE,NA, FALSE, TRUE), d=c("aa", "bb", NA, "dd"),
                 e=I(c("a1", NA, NA, "a4")))
DF$f <- as.Date(c("2001-01-01", NA, NA, "2004-10-26"))
str(DF)
write.dbf(DF, try2)
in2 <- read.dbf(try2)
str(in2)
unlink(try2)
}}
\keyword{file}
\eof
% --- Source file: write.dta.Rd ---
\name{write.dta}
\alias{write.dta}
\title{Write Files in Stata Binary Format}
\usage{
write.dta(dataframe, file, version = 6,
          convert.dates = TRUE, tz = "GMT",
          convert.factors = c("labels", "string", "numeric", "codes"))
}
\arguments{
  \item{dataframe}{a data frame.}
  \item{file}{character string giving filename.}
  \item{version}{Stata version: 6 and 7 are supported.}
  \item{convert.dates}{Convert \code{POSIXt} objects to Stata dates?}
  \item{tz}{timezone for date conversion}
  \item{convert.factors}{how to handle factors}
  } 
\description{
  Writes the data frame to file in the Stata version 6.0 or 7.0 binary
  format.  Does not write matrix variables.
}
\details{
  The major differences between Stata versions is that 7.0 allows 32-character
  variable names. The \code{abbreviate} function is used to trim long
  variables to the permitted length. A warning is given if this is needed and
  it is an error for the abbreviated names not to be unique.

  The columns in the data frame become variables in the Stata data set.
  Missing values are correctly handled.  Optionally, R date/time objects
  (\code{POSIXt} classes) are converted into the Stata format.  This loses
  information -- Stata dates are in days since 1960-1-1.  \code{POSIXct}
  objects can be written without conversion but will not be understood as
  dates by Stata;  \code{POSIXlt} objects cannot be written without
  conversion.

  There are four options for handling factors. The default is to use
  Stata \code{value labels} for the factor levels.
  With \code{convert.factors="string"}, the factor levels are written as
  strings. With \code{convert.factors="numeric"} the numeric values
  of the levels are written, or \code{NA} if they cannot be coerced to
  numeric. Finally, \code{convert.factors="codes"} writes the underlying
  integer codes of the factors. This last used to be the only available
  method and is provided largely for backwards compatibility.

  For Stata 8 or 9 use \code{version=7} -- the only advantage of Stata 8
  format is that it can represent multiple different missing value
  types, and R doesn't have them.
  }
\value{
  \code{NULL}
}
\references{
  Stata 6.0 Users Manual, Stata 7.0 Programming manual, Stata 8.0, 9.0 online
  help describe the file formats.
} 
\author{Thomas Lumley}
\seealso{
  \code{\link{read.dta}},
  \code{\link{attributes}},
  \code{\link{DateTimeClasses}},
  \code{\link{abbreviate}}
}
\examples{
write.dta(swiss, swissfile <- tempfile())
read.dta(swissfile)
}
\keyword{file}
\eof
% --- Source file: write.foreign.Rd ---
\name{write.foreign}
\alias{write.foreign}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Write Text Files and Code to Read Them}
\description{
This function exports simple data frames to other statistical packages by
writing the data as free-format text and writing a separate file of
instructions for the other package to read the data. 
}
\usage{
write.foreign(df, datafile, codefile,
              package = c("SPSS", "Stata", "SAS"), ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{df}{A data frame}
  \item{datafile}{Name of file for data output}
  \item{codefile}{Name of file for code output}
  \item{package}{Name of package}
  \item{\dots}{Other arguments for the individual \code{writeForeign} functions}
}
\details{
The work for this function is done by
\code{foreign:::writeForeignStata}, \code{foreign:::writeForeignSAS} and
\code{foreign:::writeForeignSPSS}. To add support for another package,
eg Systat, create a function \code{writeForeignSystat} with the same first
three arguments as \code{write.foreign}. This will be called from
\code{write.foreign} when \code{package="Systat"}.

Numeric variables and factors are supported for all packages, dates and times
(\code{Date}, \code{dates}, \code{date}, and \code{POSIXt} classes) are
also supported for SAS and characters are supported for SPSS.

For \code{package="SAS"} there are optional arguments \code{dataname="rdata"}
taking a string that will be the SAS data set name and
\code{validvarname} taking either \code{"V6"} or \code{"V7"}.
}
\value{
  None
}

\author{Thomas Lumley and Stephen Weigand}
\examples{
\dontrun{
datafile<-tempfile()
codefile<-tempfile()
write.foreign(esoph,datafile,codefile,package="SPSS")
file.show(datafile)
file.show(codefile)
unlink(datafile)
unlink(codefile)
}
}
\keyword{file}% at least one, from doc/KEYWORDS

\eof
